@@ -2,6 +2,7 @@
 import logging
 
 from .rest_client import AtlassianRestAPI
+from deprecated import deprecated
 
 log = logging.getLogger(__name__)
 
@@ -154,6 +155,7 @@ class Insight(AtlassianRestAPI):
     def get_comment_of_object(self, object_id):
         """
         The object id to fetch comments from
+
         :param object_id:
         :return:
         """
@@ -183,6 +185,7 @@ class Insight(AtlassianRestAPI):
     def get_all_global_icons(self):
         """
         All existing global icons
+
         :return:
         """
         url = self.url_joiner(self.api_root, "icon/global")
@@ -197,7 +200,7 @@ class Insight(AtlassianRestAPI):
         :param import_id:
         :return:
         """
-        url = self.url_joiner(self.api_root, "import/start/{import_id}")
+        url = self.url_joiner(self.api_root, "import/start/{import_id}".format(import_id=import_id))
         return self.post(url)
 
     # Index
@@ -205,6 +208,7 @@ class Insight(AtlassianRestAPI):
     def reindex_insight(self):
         """
         Should the reindex clean the index before doing the reindex
+
         :return:
         """
         if self.cloud:
@@ -215,6 +219,7 @@ class Insight(AtlassianRestAPI):
     def reindex_current_node_insight(self):
         """
         Should the reindex clean the index before doing the reindex
+
         :return:
         """
         if self.cloud:
@@ -279,22 +284,22 @@ class Insight(AtlassianRestAPI):
         url = self.url_joiner(self.api_root, "object/{id}".format(id=object_id))
         return self.get(url)
 
-    def update_object(self, object_id, objectTypeId, attributes, hasAvatar=False, avatarUUID=""):
+    def update_object(self, object_id, object_type_id, attributes, has_avatar=False, avatar_uuid=""):
         """
         Update an existing object in Insight
 
         :param object_id:
-        :param objectTypeId:
+        :param object_type_id:
         :param attributes:
-        :param hasAvatar:
-        :param avatarUUID:
+        :param has_avatar:
+        :param avatar_uuid:
         :return:
         """
         body = {
             "attributes": attributes,
-            "objectTypeId": objectTypeId,
-            "avatarUUID": avatarUUID,
-            "hasAvatar": hasAvatar,
+            "objectTypeId": object_type_id,
+            "avatarUUID": avatar_uuid,
+            "hasAvatar": has_avatar,
         }
         url = self.url_joiner(self.api_root, "object/{id}".format(id=object_id))
         return self.put(url, data=body)
@@ -313,7 +318,7 @@ class Insight(AtlassianRestAPI):
         """
         List all attributes for the given object
 
-        :param id:
+        :param object_id:
         :return:
         """
         url = self.url_joiner(self.api_root, "object/{id}/attributes".format(id=object_id))
@@ -323,7 +328,7 @@ class Insight(AtlassianRestAPI):
         """
         Retrieve the history entries for this object
 
-        :param id:
+        :param object_id:
         :param asc:
         :param abbreviate:
         :return:
@@ -332,32 +337,38 @@ class Insight(AtlassianRestAPI):
         url = self.url_joiner(self.api_root, "object/{id}/history".format(id=object_id))
         return self.get(url, params=params)
 
+    @deprecated(version="3.29.0", reason="Use get_object_reference_info()")
     def get_object_referenceinfo(self, object_id):
+        """Let's use the get_object_reference_info()"""
+        log.warning("Please, be informed that is deprecated as typo naming")
+        self.get_object_reference_info(object_id)
+
+    def get_object_reference_info(self, object_id):
         """
         Find all references for an object
 
-        :param id:
+        :param object_id:
         :return:
         """
         url = self.url_joiner(self.api_root, "object/{id}/referenceinfo".format(id=object_id))
         return self.get(url)
 
-    def create_object(self, objectTypeId, attributes, hasAvatar=False, avatarUUID=""):
+    def create_object(self, object_type_id, attributes, has_avatar=False, avatar_uuid=""):
         """
         Create a new object in Insight
 
-        :param objectTypeId:
+        :param object_type_id:
         :param attributes:
-        :param hasAvatar:
-        :param avatarUUID:
+        :param has_avatar:
+        :param avatar_uuid:
         :return:
         :return:
         """
         data = {
             "attributes": attributes,
-            "objectTypeId": objectTypeId,
-            "avatarUUID": avatarUUID,
-            "hasAvatar": hasAvatar,
+            "objectTypeId": object_type_id,
+            "avatarUUID": avatar_uuid,
+            "hasAvatar": has_avatar,
         }
         url = self.url_joiner(self.api_root, "object/create")
         return self.post(url, data=data)
@@ -365,42 +376,48 @@ class Insight(AtlassianRestAPI):
     def create_object_navlist_iql(
         self,
         iql,
-        objectTypeId,
-        resultsPerPage,
-        orderByTypeAttrId,
-        objectId,
-        objectSchemaId,
-        includeAttributes,
-        attributesToDisplay,
+        object_type_id,
+        results_per_page,
+        order_by_type_attr_id,
+        object_id,
+        object_schema_id,
+        include_attributes,
+        attributes_to_display,
         page=1,
         asc=0,
     ):
         """
-        A filter object that is used to find a paginatad result set based on an object type and an IQL query
+        A filter object that is used to find a paginated result set based on an object type and an IQL query
 
         :param iql:
-        :param objectTypeId:
+        :param object_type_id:
         :param page:
-        :param resultsPerPage:
-        :param orderByTypeAttrId:
+        :param results_per_page:
+        :param order_by_type_attr_id:
         :param asc:
-        :param objectId:
-        :param objectSchemaId:
-        :param includeAttributes:
-        :param attributesToDisplay:
+        :param object_id:
+        :param object_schema_id:
+        :param include_attributes:
+        :param attributes_to_display:
         :return:
         """
-        data = {"objectTypeId": objectTypeId, "iql": iql, "resultsPerPage": resultsPerPage, "page": page, "asc": asc}
-        if attributesToDisplay is not None:
-            data["attributesToDisplay"] = attributesToDisplay
-        if includeAttributes is not None:
-            data["includeAttributes"] = includeAttributes
-        if objectSchemaId is not None:
-            data["objectSchemaId"] = objectSchemaId
-        if orderByTypeAttrId is not None:
-            data["orderByTypeAttrId"] = orderByTypeAttrId
-        if objectId is not None:
-            data["objectId"] = objectId
+        data = {
+            "objectTypeId": object_type_id,
+            "iql": iql,
+            "resultsPerPage": results_per_page,
+            "page": page,
+            "asc": asc,
+        }
+        if attributes_to_display is not None:
+            data["attributesToDisplay"] = attributes_to_display
+        if include_attributes is not None:
+            data["includeAttributes"] = include_attributes
+        if object_schema_id is not None:
+            data["objectSchemaId"] = object_schema_id
+        if order_by_type_attr_id is not None:
+            data["orderByTypeAttrId"] = order_by_type_attr_id
+        if object_id is not None:
+            data["objectId"] = object_id
         url = self.url_joiner(self.api_root, "iql/objects")
         return self.post(url, data=data)
 
@@ -415,11 +432,14 @@ class Insight(AtlassianRestAPI):
         url = self.url_joiner(self.api_root, "objectconnectedtickets/{id}/tickets".format(id=object_id))
         return self.get(url)
 
-    # Objectschema
+    # Object schema
+    @deprecated(version="3.29.1", reason="Use list_object_schema()")
     def list_objectschema(self):
+        return self.list_object_schema()
+
+    def list_object_schema(self):
         """
         Resource to find object schemas in Insight
-
         :return:
         {
             "objectschemas": [
@@ -439,47 +459,107 @@ class Insight(AtlassianRestAPI):
         url = self.url_joiner(self.api_root, "objectschema/list")
         return self.get(url)
 
-    def create_objectschema(self, objectSchemaKey, description):
+    def create_object_schema(self, object_schema_key, description):
         raise NotImplementedError
 
+    @deprecated(version="3.29.1", reason="Use get_objectschema()")
     def get_objectschema(self, schema_id):
+        return self.get_objectschema(schema_id=schema_id)
+
+    def get_object_schema(self, schema_id):
         """
         Find a schema by id
-
         :param schema_id:
         """
         url = self.url_joiner(self.api_root, "objectschema/{id}".format(id=schema_id))
         return self.get(url)
 
-    def update_objectschema(self, schema_id):
+    def update_object_schema(self, schema_id):
         """
         Update an object schema
-
         """
         raise NotImplementedError
 
-    def delete_objectschema(self, schema_id):
+    def delete_object_schema(self, schema_id):
         """
         Delete a schema
 
         """
         raise NotImplementedError
 
-    def get_objectschema_attributes(self, schema_id):
+    def get_object_schema_attributes(self, schema_id):
         """
         Find all object type attributes for this object schema
-
         """
         raise NotImplementedError
 
-    def get_objectschema_objecttypes_flat(self, schema_id):
+    def get_object_schema_object_types_flat(self, schema_id):
         """
         Find all object types for this object schema
-
         """
         raise NotImplementedError
 
+    def get_object_type_attributes(
+        self,
+        type_id,
+        only_value_editable=None,
+        order_by_name=None,
+        query=None,
+        include_values_exist=None,
+        exclude_parent_attributes=None,
+        include_children=None,
+        order_by_required=None,
+    ):
+        """
+        Find all attributes for this object type
+        https://developer.atlassian.com/cloud/insight/rest/api-group-objecttype/#api-objecttype-id-attributes-get
+        Args:
+            type_id (str): id of the object type
+            only_value_editable (bool, optional): only return editable values, defaults to None (Use API default)
+            order_by_name (bool, optional): values, defaults to None (Use API default)
+            query (str, optional): Not documented in API, defaults to None (Use API default)
+            include_values_exist (bool, optional): Include only where values exist, defaults to None (Use API default)
+            exclude_parent_attributes (bool, optional): Exclude parent attributes, defaults to None (Use API default)
+            include_children (bool, optional): include attributes from children, defaults to None (Use API default)
+            order_by_required (bool, optional): Order by required fields, defaults to None (Use API default)
+        """
+
+        kwargs = locals().items()
+        params = dict()
+        params.update({k: v for k, v in kwargs if v is not None and k not in ["self", "type_id"]})
+
+        return self.get(
+            "{0}objecttype/{1}/attributes".format(self.api_root, type_id),
+            headers=self.experimental_headers,
+            params=params,
+        )
+
     # Objecttype
-    # Objecttypeattribute
-    # Progress
-    # Config
+    # TODO: Post objecttype {id} position:
+    #       https://developer.atlassian.com/cloud/insight/rest/api-group-objecttype/#api-objecttype-id-position-post
+    # TODO: Post objecttype create:
+    #       https://developer.atlassian.com/cloud/insight/rest/api-group-objecttype/#api-objecttype-create-post
+
+    # Insight ObjectTypeAttribute API
+    # TODO: Post objecttypeattribute {objectTypeId}:
+    #       https://developer.atlassian.com/cloud/insight/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-post
+    # TODO: Put objecttypeattribute {objectTypeId} {id}:
+    #       https://developer.atlassian.com/cloud/insight/rest/api-group-objecttypeattribute/#api-objecttypeattribute-objecttypeid-id-put
+    # TODO: Delete objecttypeattribute {id}:
+    #       https://developer.atlassian.com/cloud/insight/rest/api-group-objecttypeattribute/#api-objecttypeattribute-id-delete
+
+    # Insight Progress API
+    # TODO: Get progress category imports {id}:
+    #       https://developer.atlassian.com/cloud/insight/rest/api-group-progress/#api-progress-category-imports-id-get
+
+    # Insight Config API
+    # TODO: Get config statustype:
+    #       https://developer.atlassian.com/cloud/insight/rest/api-group-config/#api-config-statustype-get
+    # TODO: Post config statustype:
+    #       https://developer.atlassian.com/cloud/insight/rest/api-group-config/#api-config-statustype-post
+    # TODO: Get config statustype {id}:
+    #       https://developer.atlassian.com/cloud/insight/rest/api-group-config/#api-config-statustype-id-get
+    # TODO: Put config statustype {id}:
+    #       https://developer.atlassian.com/cloud/insight/rest/api-group-config/#api-config-statustype-id-put
+    # TODO: Delete config statustype {id}:
+    #       https://developer.atlassian.com/cloud/insight/rest/api-group-config/#api-config-statustype-id-delete
